<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW" sourcelanguage="en">
<context>
    <name>DialogAbout</name>
    <message>
        <location filename="../dialogabout.ui" line="14"/>
        <source>About IMSProg</source>
        <translation>關於 IMSProg</translation>
    </message>
    <message>
        <source>IMSProg - free software I2C, SPI and MicroWire EEPROM/Flash chip programmer for CH341a devices. IMSProg supports 24Cxx, 25xx, 93Cxx, and M95xx series chips.</source>
        <translation type="vanished">IMSProg - I2C、SPI、MicroWire EEPROM/Flash 晶片 CH341A 程式燒錄器免費軟體。IMSProg 支援 24Cxx、25xx、93Cxx 和 M95xx 系列晶片。</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;In this program &lt;a href=&quot;https://github.com/Simsys/qhexedit2/&quot;&gt;QhexEditor2&lt;/a&gt; widget and modified programmer &lt;a href=&quot;https://github.com/McMCCRU/SNANDer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;SNANDer&lt;/span&gt;&lt;/a&gt; were used.&lt;/p&gt;&lt;p&gt;The page on GitHub is &lt;a href=&quot;https://github.com/bigbigmdm/IMSProg&quot;&gt;here&lt;/a&gt;, the support page is &lt;a href=&quot;https://antenna-dvb-t2.ru/IMSProg.php&quot;&gt;here&lt;/a&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;本程式使用 &lt;a href=&quot;https://github.com/Simsys/qhexedit2/&quot;&gt;QhexEditor2&lt;/a&gt; 元件和經過修改的程式燒錄器 &lt;a href=&quot;https://github.com/McMCCRU/SNANDer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;SNANDer&lt;/span&gt;&lt;/a&gt; 。&lt;/p&gt;&lt;p&gt;GitHub 頁面在 &lt;a href=&quot;https://github.com/bigbigmdm/IMSProg&quot;&gt;這裡&lt;/a&gt;, 支援頁面在 &lt;a href=&quot;https://antenna-dvb-t2.ru/IMSProg.php&quot;&gt;這裡&lt;/a&gt;。 &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="120"/>
        <source>Version: </source>
        <translation>版本： </translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="130"/>
        <source>1.1.4</source>
        <translation>1.1.4</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="48"/>
        <source>OR</source>
        <translation>或</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="26"/>
        <source>IMSProg - free software I2C, SPI and MicroWire EEPROM/Flash chip programmer for CH341a devices. IMSProg supports 24Cxx, 25xx, 93Cxx, AT45DBxx and M95xx series chips.</source>
        <translation>IMSProg - I2C、SPI、MicroWire EEPROM/Flash 晶片 CH341A 程式燒錄器免費軟體。IMSProg 支援 24Cxx、25xx、93Cxx, AT45DBxx 和 M95xx 系列晶片。</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="99"/>
        <source>Written by 2023 Mikhail Medvedev</source>
        <translation>作者：2023 米哈伊爾·梅德韋傑夫</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="169"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>DialogBBM</name>
    <message>
        <location filename="../dialogbbm.ui" line="20"/>
        <source>Bad block management</source>
        <translation>壞區塊管理</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="34"/>
        <source>Chip scan</source>
        <translation>晶片掃描</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="69"/>
        <location filename="../dialogbbm.ui" line="285"/>
        <source>No</source>
        <translation>数字</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="77"/>
        <source>Block</source>
        <translation>區塊編號</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="85"/>
        <source>Start address</source>
        <translation>起始位址:</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="93"/>
        <source>End address</source>
        <translation>結束位址</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="137"/>
        <source>Check</source>
        <translation>檢查</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="147"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="167"/>
        <source>Erasing</source>
        <translation>抹除</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="173"/>
        <source>Skip bad blocks during erase procedure  (recommended)</source>
        <translation>在擦除程序中跳過壞區塊（建議）</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="180"/>
        <source>Don&apos;t skip bad blocks</source>
        <translation>不要跳過壞區塊</translation>
    </message>
    <message>
        <source>Don&apos;t skip bad sectors</source>
        <translation type="vanished">不要跳過壞軌</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="190"/>
        <source>Writing</source>
        <translation>寫作</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="196"/>
        <source>Write all blocks one to one (ignore bad blocks)</source>
        <translation>將所有區塊一對一寫入（忽略壞區塊）</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="203"/>
        <source>Skip bad blocks during writing procedure</source>
        <translation>在寫入程序中跳過壞區塊</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="256"/>
        <source>Ok</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="268"/>
        <source>BBM table (Winbond)</source>
        <translation>壞區塊管理表（Winbond）</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="274"/>
        <source>This operation is used only in some Winbond chips.</source>
        <translation>此操作僅適用於特定的華邦（Winbond）晶片。</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="290"/>
        <source>Bad block</source>
        <translation>壞區塊數量</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="295"/>
        <source>Changed block</source>
        <translation>變更區塊編號</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="300"/>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <location filename="../dialogbbm.ui" line="348"/>
        <source>Read</source>
        <translation>讀取</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="80"/>
        <location filename="../dialogbbm.cpp" line="92"/>
        <location filename="../dialogbbm.cpp" line="163"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="80"/>
        <source>Error reading chip!</source>
        <translation>讀取晶片錯誤！</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="84"/>
        <source>Corrupted blocks found:</source>
        <translation>發現損壞區塊：</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="85"/>
        <source>All blocks in the chip are good!</source>
        <translation>晶片中的所有模組都正常！</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="92"/>
        <location filename="../dialogbbm.cpp" line="163"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>CH341A 程式燒錄器未連接！</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="153"/>
        <source>Not used</source>
        <translation>未使用</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="154"/>
        <source>Active, valid</source>
        <translation>有效、有效</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="155"/>
        <source>Active, not valid</source>
        <translation>有效，非有效</translation>
    </message>
    <message>
        <location filename="../dialogbbm.cpp" line="160"/>
        <source>BBM table is not used in this chip.</source>
        <translation>此晶片未使用壞區管理表。</translation>
    </message>
</context>
<context>
    <name>DialogCompare</name>
    <message>
        <location filename="../dialogcompare.ui" line="14"/>
        <source>Comparing files:</source>
        <translation>比較檔案：</translation>
    </message>
    <message>
        <location filename="../dialogcompare.ui" line="68"/>
        <source>CRC32: </source>
        <translation>CRC32: </translation>
    </message>
    <message>
        <location filename="../dialogcompare.ui" line="100"/>
        <location filename="../dialogcompare.ui" line="187"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../dialogcompare.ui" line="155"/>
        <source>CRC32:</source>
        <translation>CRC32:</translation>
    </message>
    <message>
        <location filename="../dialogcompare.ui" line="201"/>
        <source>Visible ASCII areas</source>
        <translation>顯示 ASCII 區域</translation>
    </message>
    <message>
        <location filename="../dialogcompare.cpp" line="108"/>
        <location filename="../dialogcompare.cpp" line="109"/>
        <source>Name: </source>
        <translation>名稱：</translation>
    </message>
</context>
<context>
    <name>DialogInfo</name>
    <message>
        <location filename="../dialoginfo.ui" line="14"/>
        <source>Connection info:</source>
        <translation>連接資訊：</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="36"/>
        <source>Slot:</source>
        <translation>插槽：</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="43"/>
        <location filename="../dialoginfo.ui" line="61"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="54"/>
        <source>Adapter:</source>
        <translation>轉接器：</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="106"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>DialogNANDSr</name>
    <message>
        <location filename="../dialognandsr.ui" line="20"/>
        <source>Status registers</source>
        <translation>狀態暫存器</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="37"/>
        <source>Status register 1</source>
        <translation>狀態暫存器 1</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="318"/>
        <source>SRP0</source>
        <translation>SRP0</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="349"/>
        <source>BP3</source>
        <translation>BP3</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="380"/>
        <source>BP2</source>
        <translation>BP2</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="411"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="442"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="473"/>
        <source>TB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="504"/>
        <source>WP-E</source>
        <translation>WP-E</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="535"/>
        <source>SRP1</source>
        <translation>SRP1</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="552"/>
        <source>Status register 2</source>
        <translation>狀態暫存器 2</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="824"/>
        <source>OTP-L</source>
        <translation>OTP-L</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="852"/>
        <source>OTP-E</source>
        <translation>OTP-E</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="880"/>
        <source>SR1-L</source>
        <translation>SR1-L</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="908"/>
        <source>ECC-E</source>
        <translation>ECC-E</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="936"/>
        <source>BUF</source>
        <translation>BUF</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="964"/>
        <location filename="../dialognandsr.ui" line="992"/>
        <location filename="../dialognandsr.ui" line="1020"/>
        <location filename="../dialognandsr.ui" line="1309"/>
        <source>(R)</source>
        <translation>(R)</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1040"/>
        <source>Status register 3</source>
        <translation>狀態暫存器 3</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1337"/>
        <source>LUT-F</source>
        <translation>LUT-F</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1365"/>
        <source>ECC-1</source>
        <translation>ECC-1</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1393"/>
        <source>ECC-0</source>
        <translation>ECC-0</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1421"/>
        <source>P-FAIL</source>
        <translation>P-FAIL</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1449"/>
        <source>WELL</source>
        <translation>WELL</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1477"/>
        <source>BUSY</source>
        <translation>BUSY</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1505"/>
        <source>E_FAIL</source>
        <translation>E_FAIL</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1522"/>
        <source>Status register 4</source>
        <translation>狀態暫存器 4</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1785"/>
        <location filename="../dialognandsr.ui" line="1813"/>
        <location filename="../dialognandsr.ui" line="1841"/>
        <location filename="../dialognandsr.ui" line="1869"/>
        <location filename="../dialognandsr.ui" line="1897"/>
        <location filename="../dialognandsr.ui" line="1925"/>
        <location filename="../dialognandsr.ui" line="1953"/>
        <location filename="../dialognandsr.ui" line="1981"/>
        <location filename="../dialognandsr.ui" line="2261"/>
        <location filename="../dialognandsr.ui" line="2289"/>
        <location filename="../dialognandsr.ui" line="2317"/>
        <location filename="../dialognandsr.ui" line="2345"/>
        <location filename="../dialognandsr.ui" line="2373"/>
        <location filename="../dialognandsr.ui" line="2401"/>
        <location filename="../dialognandsr.ui" line="2429"/>
        <location filename="../dialognandsr.ui" line="2457"/>
        <source>---</source>
        <translation>---</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="1998"/>
        <source>Status register 5</source>
        <translation>狀態暫存器 5</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2482"/>
        <source>Unique ID:</source>
        <translation>唯一 ID：</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2538"/>
        <source>Read</source>
        <translation>讀取</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2564"/>
        <source>Write</source>
        <translation>寫入</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2580"/>
        <source>Parameter page:</source>
        <translation>參數頁：</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2608"/>
        <source>Manufacturer:</source>
        <translation>製造商：</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2618"/>
        <source>Model:</source>
        <translation>型號：</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2628"/>
        <source>Page size:</source>
        <translation>頁面大小:</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2635"/>
        <source>ECC size:</source>
        <translation>ECC 大小:</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2648"/>
        <source>Pages per block:</source>
        <translation>每個區塊的頁數：</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2655"/>
        <source>Block per unit:</source>
        <translation>每單位的區塊：</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2662"/>
        <source>Block size:</source>
        <translation>區塊大小：</translation>
    </message>
    <message>
        <location filename="../dialognandsr.ui" line="2678"/>
        <source>Chip size:</source>
        <translation>晶片大小：</translation>
    </message>
    <message>
        <location filename="../dialognandsr.cpp" line="101"/>
        <location filename="../dialognandsr.cpp" line="165"/>
        <location filename="../dialognandsr.cpp" line="265"/>
        <location filename="../dialognandsr.cpp" line="312"/>
        <location filename="../dialognandsr.cpp" line="369"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../dialognandsr.cpp" line="101"/>
        <source>Error reading register!</source>
        <translation>讀取暫存器錯誤！</translation>
    </message>
    <message>
        <location filename="../dialognandsr.cpp" line="165"/>
        <source>Error reading Parameter Page!</source>
        <translation>錯誤讀取參數頁面!</translation>
    </message>
    <message>
        <location filename="../dialognandsr.cpp" line="247"/>
        <source>The Parameter Page is not supported.</source>
        <translation>不支援參數頁。</translation>
    </message>
    <message>
        <location filename="../dialognandsr.cpp" line="265"/>
        <source>Error reading ID!</source>
        <translation>錯誤讀取 ID！</translation>
    </message>
    <message>
        <location filename="../dialognandsr.cpp" line="312"/>
        <location filename="../dialognandsr.cpp" line="369"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>CH341A 程式燒錄器未連接！</translation>
    </message>
</context>
<context>
    <name>DialogNandSecurity</name>
    <message>
        <location filename="../dialognandsecurity.ui" line="14"/>
        <source>Security registers</source>
        <translation>安全暫存器</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.ui" line="24"/>
        <source>Hex Editor</source>
        <translation>十六進位編輯器</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.ui" line="64"/>
        <source>Operations:</source>
        <translation>操作：</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.ui" line="93"/>
        <source>Reading security register data from the chip</source>
        <translation>從晶片讀取安全暫存器資料</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.ui" line="96"/>
        <location filename="../dialognandsecurity.ui" line="128"/>
        <location filename="../dialognandsecurity.ui" line="167"/>
        <location filename="../dialognandsecurity.ui" line="199"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.ui" line="125"/>
        <source>Writing data to the security register</source>
        <translation>向安全暫存器寫入資料</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.ui" line="164"/>
        <source>Open a binary file from a computer</source>
        <translation>從電腦開啟二進位檔案</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.ui" line="196"/>
        <source>Save the binary file on the computer</source>
        <translation>在電腦上儲存二進位檔案</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.ui" line="225"/>
        <source>Security register number:</source>
        <translation>安全暫存器編號：</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.cpp" line="80"/>
        <location filename="../dialognandsecurity.cpp" line="120"/>
        <location filename="../dialognandsecurity.cpp" line="215"/>
        <location filename="../dialognandsecurity.cpp" line="233"/>
        <location filename="../dialognandsecurity.cpp" line="266"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.cpp" line="80"/>
        <source>Error reading Parameter Page!</source>
        <translation>錯誤讀取參數頁面!</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.cpp" line="120"/>
        <location filename="../dialognandsecurity.cpp" line="215"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>CH341A 程式燒錄器未連接！</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.cpp" line="224"/>
        <source>Open file</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.cpp" line="233"/>
        <source>The file size exceeds the security register size.</source>
        <translation>檔案大小超過安全暫存器大小。</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.cpp" line="255"/>
        <source>Save file</source>
        <translation>儲存檔案</translation>
    </message>
    <message>
        <location filename="../dialognandsecurity.cpp" line="266"/>
        <source>Error saving file!</source>
        <translation>儲存檔案時發生錯誤！</translation>
    </message>
</context>
<context>
    <name>DialogRP</name>
    <message>
        <location filename="../dialogrp.ui" line="20"/>
        <source>Load block from file</source>
        <translation>從檔案中載入資料區塊</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="33"/>
        <source>All values in HEX format!</source>
        <translation>所有數值均為 HEX 格式！</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="48"/>
        <source>Start address:</source>
        <translation>起始位址:</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="112"/>
        <source>Load</source>
        <translation>載入</translation>
    </message>
</context>
<context>
    <name>DialogSFDP</name>
    <message>
        <location filename="../dialogsfdp.ui" line="14"/>
        <source>Information about SFDP and status registers</source>
        <translation>有關 SFDP 和狀態暫存器的資訊</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="47"/>
        <source>SFDP support:</source>
        <translation>SFDP 支援：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="67"/>
        <source>Minimum VCC:</source>
        <translation>最低 VCC：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="87"/>
        <source>Maximum VCC:</source>
        <translation>最大 VCC：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="107"/>
        <source>Chip size:</source>
        <translation>晶片大小：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="127"/>
        <source>Block size:</source>
        <translation>區塊大小：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="150"/>
        <source>Speeds:</source>
        <translation>速度：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="170"/>
        <source>OTP support:</source>
        <translation>支援 OTP：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="196"/>
        <source>Status Register 0</source>
        <translation>狀態暫存器 0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="424"/>
        <source>SPR0</source>
        <translation>SPR0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="449"/>
        <source>BP4</source>
        <translation>BP4</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="474"/>
        <source>BP3</source>
        <translation>BP3</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="499"/>
        <source>BP2</source>
        <translation>BP2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="524"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="549"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="574"/>
        <source>WEL</source>
        <translation>WEL</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="599"/>
        <source>WIP</source>
        <translation>WIP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="830"/>
        <source>SUS1</source>
        <translation>SUS1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="855"/>
        <source>CMP</source>
        <translation>CMP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="880"/>
        <source>LB3</source>
        <translation>LB3</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="905"/>
        <source>LB2</source>
        <translation>LB2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="930"/>
        <source>LB1</source>
        <translation>LB1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="955"/>
        <source>SUS2</source>
        <translation>SUS2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="980"/>
        <source>QE</source>
        <translation>QE</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1005"/>
        <source>SPR1</source>
        <translation>SPR1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="611"/>
        <source>Status Register 1</source>
        <translation>狀態暫存器 1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1017"/>
        <source>Status register 2</source>
        <translation>狀態暫存器 2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1195"/>
        <source>JEDEC info:</source>
        <translation>JEDEC 資訊：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1301"/>
        <source>Man. ID</source>
        <translation>製造商識別碼：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1323"/>
        <source>Man. type</source>
        <translation>製造類型：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1345"/>
        <source>Capacity</source>
        <translation>容量：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1357"/>
        <source>Unique ID:</source>
        <translation>唯一 ID：</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1398"/>
        <source>Read</source>
        <translation>讀取</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1426"/>
        <source>Write registers</source>
        <translation>寫入暫存器</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1453"/>
        <location filename="../dialogsfdp.ui" line="1519"/>
        <location filename="../dialogsfdp.ui" line="1541"/>
        <source>(R)</source>
        <translation>(R)</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1475"/>
        <source>DRV1</source>
        <translation>DRV1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1497"/>
        <source>DRV0</source>
        <translation>DRV0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1563"/>
        <source>WPS</source>
        <translation>WPS</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1585"/>
        <source>ADP</source>
        <translation>ADP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1607"/>
        <source>ADS</source>
        <translation>ADS</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1693"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p/&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p/&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1731"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Legend:&lt;/p&gt;&lt;p&gt;** - Basic area&lt;br&gt;** - Extended area&lt;br&gt;** - Manufacture area &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;圖例:&lt;/p&gt;&lt;p&gt;** - 基本區域&lt;br&gt;** - 擴充區&lt;br&gt;** - 製造商區&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1776"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="83"/>
        <location filename="../dialogsfdp.cpp" line="103"/>
        <location filename="../dialogsfdp.cpp" line="212"/>
        <location filename="../dialogsfdp.cpp" line="225"/>
        <location filename="../dialogsfdp.cpp" line="244"/>
        <location filename="../dialogsfdp.cpp" line="266"/>
        <location filename="../dialogsfdp.cpp" line="281"/>
        <location filename="../dialogsfdp.cpp" line="434"/>
        <location filename="../dialogsfdp.cpp" line="436"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="103"/>
        <location filename="../dialogsfdp.cpp" line="212"/>
        <location filename="../dialogsfdp.cpp" line="225"/>
        <location filename="../dialogsfdp.cpp" line="244"/>
        <source>Error reading register!</source>
        <translation>讀取暫存器錯誤！</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="175"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Hex SFDP register data:
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; 十六進位 SFDP 暫存器資料:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="176"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Addr:&lt;br&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;位址：&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="436"/>
        <source>Before writing the registers, please press the `Read` button!</source>
        <translation>在寫入暫存器之前，請按`讀取`按鈕！</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="83"/>
        <source>Error reading JEDEC ID!</source>
        <translation>讀取 JEDEC ID 時發生錯誤！</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="43"/>
        <source>Legend:</source>
        <translation>圖例:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="44"/>
        <source> - Basic area</source>
        <translation> - 基本區域</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="45"/>
        <source> - Extended area</source>
        <translation> - 擴充區</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="46"/>
        <source> - Manufacture area</source>
        <translation> - 製造商區</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="266"/>
        <source>Error reading unique ID!</source>
        <translation>讀取唯一 ID 時發生錯誤！</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="281"/>
        <location filename="../dialogsfdp.cpp" line="434"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>CH341A 程式燒錄器未連接！</translation>
    </message>
</context>
<context>
    <name>DialogSP</name>
    <message>
        <location filename="../dialogsp.ui" line="14"/>
        <source>Save part of image</source>
        <translation>儲存部分映像</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="27"/>
        <source>All values in HEX format!</source>
        <translation>所有數值均為 HEX 格式！</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="42"/>
        <source>Start address:</source>
        <translation>起始位址:</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="120"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../dialogsp.cpp" line="28"/>
        <source>End address</source>
        <translation>結束位址</translation>
    </message>
    <message>
        <location filename="../dialogsp.cpp" line="29"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
</context>
<context>
    <name>DialogSR</name>
    <message>
        <location filename="../dialogsr.ui" line="14"/>
        <source>Status register</source>
        <translation>狀態暫存器</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="296"/>
        <source>WPEN</source>
        <translation>WPEN</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="327"/>
        <location filename="../dialogsr.ui" line="358"/>
        <location filename="../dialogsr.ui" line="389"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="420"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="451"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="482"/>
        <source>WEN</source>
        <translation>WEN</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="513"/>
        <source>/RDY</source>
        <translation>/RDY</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="545"/>
        <source>Read</source>
        <translation>讀取</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="571"/>
        <source>Write</source>
        <translation>寫入</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="56"/>
        <location filename="../dialogsr.cpp" line="70"/>
        <location filename="../dialogsr.cpp" line="109"/>
        <location filename="../dialogsr.cpp" line="112"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="56"/>
        <source>Error reading register!</source>
        <translation>讀取暫存器錯誤！</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="70"/>
        <location filename="../dialogsr.cpp" line="112"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>CH341A 程式燒錄器未連接！</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="109"/>
        <source>Before writing the register, please press the `Read` button!</source>
        <translation>在寫入暫存器之前，請按`讀取`按鈕！</translation>
    </message>
</context>
<context>
    <name>DialogSecurity</name>
    <message>
        <location filename="../dialogsecurity.ui" line="14"/>
        <source>Security registers</source>
        <translation>安全暫存器</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="24"/>
        <source>Hex Editor</source>
        <translation>十六進位編輯器</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="64"/>
        <source>Operations:</source>
        <translation>操作：</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="93"/>
        <source>Reading security register data from the chip</source>
        <translation>從晶片讀取安全暫存器資料</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="96"/>
        <location filename="../dialogsecurity.ui" line="128"/>
        <location filename="../dialogsecurity.ui" line="160"/>
        <location filename="../dialogsecurity.ui" line="199"/>
        <location filename="../dialogsecurity.ui" line="231"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="125"/>
        <source>Erasing security register data</source>
        <translation>清除安全暫存器資料</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="157"/>
        <source>Writing data to the security register</source>
        <translation>向安全暫存器寫入資料</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="196"/>
        <source>Open a binary file from a computer</source>
        <translation>從電腦開啟二進位檔案</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="228"/>
        <source>Save the binary file on the computer</source>
        <translation>在電腦上儲存二進位檔案</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="257"/>
        <source>Security register number:</source>
        <translation>安全暫存器編號：</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="171"/>
        <location filename="../dialogsecurity.cpp" line="181"/>
        <location filename="../dialogsecurity.cpp" line="255"/>
        <location filename="../dialogsecurity.cpp" line="292"/>
        <location filename="../dialogsecurity.cpp" line="361"/>
        <location filename="../dialogsecurity.cpp" line="386"/>
        <location filename="../dialogsecurity.cpp" line="419"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="171"/>
        <source>Error reading register!</source>
        <translation>讀取暫存器錯誤！</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="181"/>
        <location filename="../dialogsecurity.cpp" line="292"/>
        <location filename="../dialogsecurity.cpp" line="361"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>CH341A 程式燒錄器未連接！</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="255"/>
        <source>Error writing register!</source>
        <translation>寫入暫存器錯誤！</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="377"/>
        <source>Open file</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="386"/>
        <source>The file size exceeds the security register size.</source>
        <translation>檔案大小超過安全暫存器大小。</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="408"/>
        <source>Save file</source>
        <translation>儲存檔案</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="419"/>
        <source>Error saving file!</source>
        <translation>儲存檔案時發生錯誤！</translation>
    </message>
</context>
<context>
    <name>DialogSetAddr</name>
    <message>
        <location filename="../dialogsetaddr.ui" line="14"/>
        <source>Goto address</source>
        <translation>前往位址</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="24"/>
        <source>All values in HEX format!</source>
        <translation>所有數值均為 HEX 格式！</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="39"/>
        <source>Address:</source>
        <translation>位址:</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="90"/>
        <source>Go to</source>
        <translation>前往</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="1006"/>
        <source>File</source>
        <translation>檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1113"/>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1137"/>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1125"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>IMSProg - I2C/MicroWire/SPI CH341a Programmer</source>
        <translation>IMSProg - I2C/MicroWire/SPI CH341a 程式燒錄器</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <location filename="../mainwindow.ui" line="1024"/>
        <source>Chip</source>
        <translation>晶片</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Page size</source>
        <translation>頁面大小</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <source>Block size</source>
        <translation>區塊大小</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>VCC, Volt</source>
        <translation>VCC(伏)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>4byte Addr.</source>
        <translation>4 位元組位址</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <location filename="../mainwindow.ui" line="1149"/>
        <source>Detect</source>
        <translation>偵測</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <location filename="../mainwindow.ui" line="1161"/>
        <source>Read</source>
        <translation>讀取</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>i</source>
        <translation>i</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="461"/>
        <source>I2C bus speed</source>
        <translation>I2C 匯流排速度</translation>
    </message>
    <message>
        <source>Erase size</source>
        <translation type="vanished">擦除大小</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>ECC size</source>
        <translation>ECC 大小</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Auto Options</source>
        <translation>自動選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="664"/>
        <location filename="../mainwindow.ui" line="1173"/>
        <source>Erase</source>
        <translation>清除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Program</source>
        <translation>程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="684"/>
        <location filename="../mainwindow.ui" line="1197"/>
        <source>Verify</source>
        <translation>驗證</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="739"/>
        <source>Go!</source>
        <translation>開始！</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <location filename="../mainwindow.ui" line="1038"/>
        <source>Hex Editor</source>
        <translation>十六進位編輯器</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="846"/>
        <source>  JEDEC ID:</source>
        <translation>JEDEC ID:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="862"/>
        <source>CH341a:</source>
        <translation>CH341A:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="893"/>
        <source>border: 2px solid gray;border-radius: 5px;font-weight:600;border-style:inset;</source>
        <translation>border: 2px solid gray;border-radius: 5px;font-weight:600;border-style:inset;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="906"/>
        <source>CRC32:</source>
        <translation>CRC32:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="965"/>
        <source>Message</source>
        <translation>訊息</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Programmer</source>
        <translation>程式燒錄器</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1053"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1152"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1164"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1176"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1185"/>
        <source>Write</source>
        <translation>寫入</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1188"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1209"/>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1212"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1221"/>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1224"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1334"/>
        <source>Import from Intel HEX</source>
        <translation>從 Intel HEX 匯入</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1343"/>
        <source>Export to Intel HEX</source>
        <translation>匯出為 Intel HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1352"/>
        <source>Extract from ASUS CAP</source>
        <translation>從 ASUS CAP 提取</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1361"/>
        <source>Goto address</source>
        <translation>前往位址</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1364"/>
        <source>Move the cursor to the entered address</source>
        <translation>將游標移至輸入的位址</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1367"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1376"/>
        <source>Security registers</source>
        <translation>安全暫存器</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1379"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1388"/>
        <source>Fill test image</source>
        <translation>填充測試映像</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1391"/>
        <source>Filling the hex editor with a test array</source>
        <translation>用測試陣列填充十六進位編輯器</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1394"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1403"/>
        <source>Compare files</source>
        <translation>比較檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1406"/>
        <source>Compares the results of the last and penultimate chip read or file open operation</source>
        <translation>比較最後一次和倒數第二次晶片讀取或檔案開啟操作的結果</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1409"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1418"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1427"/>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Bad block management</source>
        <translation>壞區塊管理</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1439"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1451"/>
        <source>CH341A/B v1.2</source>
        <translation>CH341A/B v1.2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1459"/>
        <source>CH341A v1.7</source>
        <translation>CH341A v1.7</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Save Part</source>
        <translation>部分儲存</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>Load Part</source>
        <translation>部分載入</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1257"/>
        <source>Find / Replace</source>
        <translation>尋找/取代</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1260"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1265"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1268"/>
        <source>About IMSProgrammer</source>
        <translation>關於 IMSProg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1280"/>
        <source>Checksum calculate</source>
        <translation>計算校驗和</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1283"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1292"/>
        <source>Edit chips Database</source>
        <translation>編輯晶片資料庫</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1295"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1304"/>
        <location filename="../mainwindow.cpp" line="1845"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1307"/>
        <source>Forced stop of read, write, erase and verification operations</source>
        <translation>強制停止讀取、寫入、清除和驗證操作</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1310"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1319"/>
        <source>Chip info</source>
        <translation>晶片資訊</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1322"/>
        <source>Information about SFDP and status registers</source>
        <translation>有關 SFDP 和狀態暫存器的資訊</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1325"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="883"/>
        <location filename="../mainwindow.cpp" line="926"/>
        <location filename="../mainwindow.cpp" line="1446"/>
        <location filename="../mainwindow.cpp" line="2127"/>
        <location filename="../mainwindow.cpp" line="2203"/>
        <source>Current file: </source>
        <translation>目前檔案： </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Type</source>
        <translation>類型</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Manufacture</source>
        <translation>製造商</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1910"/>
        <source>Opening DAT file</source>
        <translation>開啟 DAT 檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../mainwindow.cpp" line="286"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="320"/>
        <location filename="../mainwindow.cpp" line="332"/>
        <location filename="../mainwindow.cpp" line="349"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="635"/>
        <location filename="../mainwindow.cpp" line="652"/>
        <location filename="../mainwindow.cpp" line="671"/>
        <location filename="../mainwindow.cpp" line="716"/>
        <location filename="../mainwindow.cpp" line="766"/>
        <location filename="../mainwindow.cpp" line="813"/>
        <location filename="../mainwindow.cpp" line="876"/>
        <location filename="../mainwindow.cpp" line="916"/>
        <location filename="../mainwindow.cpp" line="988"/>
        <location filename="../mainwindow.cpp" line="1050"/>
        <location filename="../mainwindow.cpp" line="1059"/>
        <location filename="../mainwindow.cpp" line="1066"/>
        <location filename="../mainwindow.cpp" line="1087"/>
        <location filename="../mainwindow.cpp" line="1097"/>
        <location filename="../mainwindow.cpp" line="1257"/>
        <location filename="../mainwindow.cpp" line="1308"/>
        <location filename="../mainwindow.cpp" line="1317"/>
        <location filename="../mainwindow.cpp" line="1323"/>
        <location filename="../mainwindow.cpp" line="1334"/>
        <location filename="../mainwindow.cpp" line="1358"/>
        <location filename="../mainwindow.cpp" line="1359"/>
        <location filename="../mainwindow.cpp" line="1373"/>
        <location filename="../mainwindow.cpp" line="1402"/>
        <location filename="../mainwindow.cpp" line="1426"/>
        <location filename="../mainwindow.cpp" line="1460"/>
        <location filename="../mainwindow.cpp" line="1743"/>
        <location filename="../mainwindow.cpp" line="1919"/>
        <location filename="../mainwindow.cpp" line="2079"/>
        <location filename="../mainwindow.cpp" line="2093"/>
        <location filename="../mainwindow.cpp" line="2217"/>
        <location filename="../mainwindow.cpp" line="2249"/>
        <location filename="../mainwindow.cpp" line="2267"/>
        <location filename="../mainwindow.cpp" line="2287"/>
        <location filename="../mainwindow.cpp" line="2418"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1743"/>
        <source>File &apos;IMSProg_editor&apos; not found!</source>
        <translation>找不到檔案 `IMSProg_editor`！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1919"/>
        <source>Error loading chip database file!</source>
        <translation>載入晶片資料庫檔案時發生錯誤！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1925"/>
        <source>Parsing DAT file</source>
        <translation>解析 DAT 檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>Reading data from </source>
        <translation>讀取資料來源 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../mainwindow.cpp" line="988"/>
        <location filename="../mainwindow.cpp" line="1050"/>
        <location filename="../mainwindow.cpp" line="1257"/>
        <location filename="../mainwindow.cpp" line="1308"/>
        <source>Unsupported chip type!</source>
        <translation>不支援的晶片類型！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <location filename="../mainwindow.cpp" line="332"/>
        <location filename="../mainwindow.cpp" line="349"/>
        <location filename="../mainwindow.cpp" line="652"/>
        <location filename="../mainwindow.cpp" line="1059"/>
        <location filename="../mainwindow.cpp" line="1097"/>
        <location filename="../mainwindow.cpp" line="1317"/>
        <location filename="../mainwindow.cpp" line="1373"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>CH341A 程式燒錄器未連接！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="1323"/>
        <source>Error reading block </source>
        <translation>讀取區塊時發生錯誤 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="1087"/>
        <location filename="../mainwindow.cpp" line="1358"/>
        <source>Before reading from chip please press &apos;Detect&apos; button.</source>
        <translation>讀取晶片資料前，請按下 &apos;偵測&apos; 按鈕。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Please select the chip parameters - manufacture and chip name</source>
        <translation>請選擇晶片參數 - &apos;製造商&apos; 和晶片 &apos;名稱&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>The chip is not connect or missing!</source>
        <translation>晶片未連接或遺失！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <location filename="../mainwindow.cpp" line="2118"/>
        <source>Saving file</source>
        <translation>儲存檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <location filename="../mainwindow.cpp" line="2120"/>
        <source>Save file</source>
        <translation>儲存檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <location filename="../mainwindow.cpp" line="1426"/>
        <source>Error saving file!</source>
        <translation>儲存檔案時發生錯誤！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="655"/>
        <source>Erasing the </source>
        <translation>正在清除 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <location filename="../mainwindow.cpp" line="716"/>
        <location filename="../mainwindow.cpp" line="766"/>
        <location filename="../mainwindow.cpp" line="813"/>
        <source>Error erasing sector </source>
        <translation>清除磁區時發生錯誤 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="854"/>
        <location filename="../mainwindow.cpp" line="904"/>
        <location filename="../mainwindow.cpp" line="2189"/>
        <source>Opening file</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <location filename="../mainwindow.cpp" line="908"/>
        <location filename="../mainwindow.cpp" line="2193"/>
        <source>Open file</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <location filename="../mainwindow.cpp" line="916"/>
        <source>The file size exceeds the chip size. Please select another chip or file or use `Save part` to split the file.</source>
        <translation>檔案大小超過晶片容量。請選擇其他晶片或檔案，或使用「部分儲存」分割檔案。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="998"/>
        <source>Writing data to </source>
        <translation>正在寫入資料至 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>Error writing sector </source>
        <translation>寫入磁區時發生錯誤 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1273"/>
        <source>Veryfing data from </source>
        <translation>正在驗證資料來源 </translation>
    </message>
    <message>
        <source>Error comparing data!
    Address:   </source>
        <translation type="vanished">比對資料時發生錯誤！
    位址：   </translation>
    </message>
    <message>
        <source>
    Buffer: </source>
        <translation type="vanished">
    緩衝區： </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1334"/>
        <source>    Chip: </source>
        <translation>    晶片： </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1334"/>
        <source>Error comparing data!
Address:   </source>
        <translation>比較資料時出錯！
地址：   </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1334"/>
        <source>
Buffer: </source>
        <translation>
緩衝： </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <location filename="../mainwindow.cpp" line="2418"/>
        <source>Please select the chip parameters - manufacture and chip name.</source>
        <translation>請選擇晶片參數 - &apos;製造商&apos; 和晶片 &apos;名稱&apos;。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1368"/>
        <source>Ok!</source>
        <translation>確定！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1368"/>
        <source>The operation was successful!</source>
        <translation>操作成功！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>The end address must be greater than the starting address.</source>
        <translation>結束位址必須大於起始位址。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1414"/>
        <source>Saving block</source>
        <translation>儲存區塊</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1416"/>
        <source>Save block</source>
        <translation>儲存區塊</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1441"/>
        <source>Opening block</source>
        <translation>開啟區塊</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1443"/>
        <source>Open block</source>
        <translation>開啟區塊</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1460"/>
        <source>The end address out of image size!</source>
        <translation>結束位址超出映像檔大小！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1498"/>
        <source>Connected</source>
        <translation>已連接</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1503"/>
        <source>Not connected</source>
        <translation>未連接</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2079"/>
        <source>Before working with the security registers, click the &apos;Detect&apos; button</source>
        <translation>在使用安全暫存器之前，請點擊 &apos;偵測&apos;按鈕</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2093"/>
        <source>There are no security registers in this chip or the current version of IMSProg does not support this algorithm.</source>
        <translation>此晶片沒有安全暫存器，或目前版本的 IMSProg 不支援此演算法。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2217"/>
        <source>Not valid HEX format!</source>
        <translation>無效的 HEX 格式！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2249"/>
        <source>The address is larger than the size of the chip!</source>
        <translation>位址大於晶片容量！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2267"/>
        <location filename="../mainwindow.cpp" line="2287"/>
        <source>Checksum error!</source>
        <translation>校驗和錯誤！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1845"/>
        <source>Operation aborted!</source>
        <translation>操作已中止！</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../searchdialog.ui" line="14"/>
        <source>QHexEdit - Find/Replace</source>
        <translation>QHexEdit - 尋找/取代</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="26"/>
        <source>Find</source>
        <translation>尋找</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="33"/>
        <location filename="../searchdialog.ui" line="78"/>
        <source>Hex</source>
        <translation>Hex</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="38"/>
        <location filename="../searchdialog.ui" line="83"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="71"/>
        <source>Replace</source>
        <translation>取代</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="116"/>
        <source>Options</source>
        <translation>選項:</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="122"/>
        <source>&amp;Backwards</source>
        <translation>向後(&amp;B)</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="129"/>
        <source>&amp;Prompt on replace</source>
        <translation>取代時提示(&amp;P)</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="150"/>
        <source>Standard headers:</source>
        <translation>標準標頭：</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="191"/>
        <source>ZIP</source>
        <translation>ZIP</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="213"/>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="235"/>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="257"/>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="286"/>
        <source>TAR</source>
        <translation>TAR</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="308"/>
        <source>UEFI</source>
        <translation>UEFI</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="330"/>
        <source>BIOS</source>
        <translation>BIOS</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="352"/>
        <source>GPT</source>
        <translation>GPT</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="385"/>
        <source>&amp;Find</source>
        <translation>尋找(&amp;F)</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="388"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="413"/>
        <source>&amp;Replace</source>
        <translation>取代(&amp;R)</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="435"/>
        <source>Replace &amp;All</source>
        <translation>全部取代(&amp;A)</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="457"/>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="91"/>
        <location filename="../searchdialog.cpp" line="117"/>
        <source>QHexEdit</source>
        <translation>QHexEdit</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="91"/>
        <source>%1 occurrences replaced.</source>
        <translation>已取代 %1 個項目。</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="118"/>
        <source>Replace occurrence?</source>
        <translation>要取代此項目嗎？</translation>
    </message>
</context>
<context>
    <name>UndoStack</name>
    <message>
        <location filename="../commands.cpp" line="133"/>
        <source>Inserting %1 bytes</source>
        <translation>插入 %1 位元組</translation>
    </message>
    <message>
        <location filename="../commands.cpp" line="155"/>
        <source>Delete %1 chars</source>
        <translation>刪除 %1 個字元</translation>
    </message>
    <message>
        <location filename="../commands.cpp" line="180"/>
        <source>Overwrite %1 chars</source>
        <translation>覆寫 %1 個字元</translation>
    </message>
</context>
</TS>
